@@ -1,7 +1,7 @@
 /* chartype.c
  *  Copyright: (When this is determined...it will go here)
  *  CVS Info
- *     $Id: chartype.c,v 1.1 2001/10/31 22:51:31 tom Exp $
+ *     $Id: chartype.c,v 1.4 2002/03/17 06:44:41 josh Exp $
  *  Overview:
  *     This defines the string character type subsystem
  *  Data Structure and Algorithms:
@@ -15,8 +15,11 @@
 extern const CHARTYPE usascii_chartype;
 extern const CHARTYPE unicode_chartype;
 
+static const CHARTYPE *chartype_array[enum_chartype_MAX];
+
 const CHARTYPE *
-chartype_lookup(const char *name) {
+chartype_lookup(const char *name)
+{
     if (strcmp(name, "usascii") == 0) {
         return &usascii_chartype;
     }
@@ -28,8 +31,19 @@ chartype_lookup(const char *name) {
     }
 }
 
+const CHARTYPE *
+chartype_lookup_index(INTVAL n)
+{
+    if (!chartype_array[0]) {
+        chartype_array[enum_chartype_unicode] = &unicode_chartype;
+        chartype_array[enum_chartype_usascii] = &usascii_chartype;
+    }
+    return chartype_array[n];
+}
+
 CHARTYPE_TRANSCODER
-chartype_lookup_transcoder(const CHARTYPE *from, const CHARTYPE *to) {
+chartype_lookup_transcoder(const CHARTYPE *from, const CHARTYPE *to)
+{
     CHARTYPE_TRANSCODER transcoder;
 
     if ((transcoder = from->transcode_to(to->name)) == NULL) {
