@@ -1,7 +1,7 @@
 /* encoding.c
  *  Copyright: (When this is determined...it will go here)
  *  CVS Info
- *     $Id: encoding.c,v 1.1 2001/10/31 22:51:31 tom Exp $
+ *     $Id: encoding.c,v 1.4 2002/03/17 06:44:41 josh Exp $
  *  Overview:
  *     This defines the string encoding subsystem
  *  Data Structure and Algorithms:
@@ -17,8 +17,11 @@ extern const ENCODING utf8_encoding;
 extern const ENCODING utf16_encoding;
 extern const ENCODING utf32_encoding;
 
+static const ENCODING *encoding_array[enum_encoding_MAX];
+
 const ENCODING *
-encoding_lookup(const char *name) {
+encoding_lookup(const char *name)
+{
     if (strcmp(name, "singlebyte") == 0) {
         return &singlebyte_encoding;
     }
@@ -36,6 +39,18 @@ encoding_lookup(const char *name) {
     }
 }
 
+const ENCODING *
+encoding_lookup_index(INTVAL n)
+{
+    if (!encoding_array[0]) {
+        encoding_array[enum_encoding_singlebyte] = &singlebyte_encoding;
+        encoding_array[enum_encoding_utf8]       = &utf8_encoding;
+        encoding_array[enum_encoding_utf16]      = &utf16_encoding;
+        encoding_array[enum_encoding_utf32]      = &utf32_encoding;
+    }
+    return encoding_array[n];
+}
+
 /*
  * Local variables:
  * c-indentation-style: bsd
