@@ -1,7 +1,7 @@
 /* singlebyte.c
  *  Copyright: (When this is determined...it will go here)
  *  CVS Info
- *     $Id: singlebyte.c,v 1.5 2001/12/06 00:11:24 tom Exp $
+ *     $Id: singlebyte.c,v 1.14 2002/03/12 11:34:01 simon Exp $
  *  Overview:
  *     This defines the single byte encoding routines.
  *  Data Structure and Algorithms:
@@ -14,47 +14,53 @@
 
 typedef unsigned char byte_t;
 
-static INTVAL
-singlebyte_characters (const void *ptr, INTVAL bytes) {
+static UINTVAL
+singlebyte_characters(const void *ptr, UINTVAL bytes)
+{
+    UNUSED(ptr);
+
     return bytes;
 }
 
-static INTVAL
-singlebyte_decode (const void *ptr) {
-    const byte_t *bptr = ptr;
-
-    return *bptr;
+static UINTVAL
+singlebyte_decode(const void *ptr)
+{
+    return *(const byte_t *)ptr;
 }
 
 static void *
-singlebyte_encode (void *ptr, INTVAL c) {
-    byte_t *bptr = ptr;
+singlebyte_encode(void *ptr, UINTVAL c)
+{
+    byte_t *bptr = (byte_t *)ptr;
 
-    if (c < 0 || c > 255) {
-        INTERNAL_EXCEPTION(INVALID_CHARACTER,
+    if (c > 255) {
+        internal_exception(INVALID_CHARACTER,
                            "Invalid character for single byte encoding\n");
     }
 
-    *bptr = c;
+    *bptr = (byte_t)c;
 
     return bptr + 1;
 }
 
 static void *
-singlebyte_skip_forward (void *ptr, INTVAL n) {
-    byte_t *bptr = ptr;
+singlebyte_skip_forward(const void *ptr, UINTVAL n)
+{
+    byte_t *bptr = (byte_t *)ptr;
 
     return bptr + n;
 }
 
 static void *
-singlebyte_skip_backward (void *ptr, INTVAL n) {
-    byte_t *bptr = ptr;
+singlebyte_skip_backward(const void *ptr, UINTVAL n)
+{
+    byte_t *bptr = (byte_t *)ptr;
 
     return bptr - n;
 }
 
 const ENCODING singlebyte_encoding = {
+    enum_encoding_singlebyte,
     "singlebyte",
     1,
     singlebyte_characters,
