@@ -1,7 +1,7 @@
 /* utf32.c
  *  Copyright: (When this is determined...it will go here)
  *  CVS Info
- *     $Id: utf32.c,v 1.1 2001/10/31 22:51:31 tom Exp $
+ *     $Id: utf32.c,v 1.9 2002/03/12 11:34:01 simon Exp $
  *  Overview:
  *     This defines the UTF-32 encoding routines.
  *  Data Structure and Algorithms:
@@ -17,24 +17,29 @@
 typedef unsigned long utf32_t;
 #endif
 
-static INTVAL
-utf32_characters (const void *ptr, INTVAL bytes) {
+static UINTVAL
+utf32_characters(const void *ptr, UINTVAL bytes)
+{
+    UNUSED(ptr);
+
     return bytes / 4;
 }
 
-static INTVAL
-utf32_decode (const void *ptr) {
+static UINTVAL
+utf32_decode(const void *ptr)
+{
     const utf32_t *u32ptr = ptr;
 
     return *u32ptr;
 }
 
 static void *
-utf32_encode (void *ptr, INTVAL c) {
-    utf32_t *u32ptr = ptr;
+utf32_encode(void *ptr, UINTVAL c)
+{
+    utf32_t *u32ptr = (utf32_t *)ptr;
 
-    if (c < 0 || c > 0x10FFFF || UNICODE_IS_SURROGATE(c)) {
-        INTERNAL_EXCEPTION(INVALID_CHARACTER,
+    if (c > 0x10FFFF || UNICODE_IS_SURROGATE(c)) {
+        internal_exception(INVALID_CHARACTER,
                            "Invalid character for UTF-32 encoding\n");
     }
 
@@ -44,20 +49,23 @@ utf32_encode (void *ptr, INTVAL c) {
 }
 
 static void *
-utf32_skip_forward (void *ptr, INTVAL n) {
-    utf32_t *u32ptr = ptr;
+utf32_skip_forward(const void *ptr, UINTVAL n)
+{
+    utf32_t *u32ptr = (utf32_t *)ptr;
 
     return u32ptr + n;
 }
 
 static void *
-utf32_skip_backward (void *ptr, INTVAL n) {
-    utf32_t *u32ptr = ptr;
+utf32_skip_backward(const void *ptr, UINTVAL n)
+{
+    utf32_t *u32ptr = (utf32_t *)ptr;
 
     return u32ptr - n;
 }
 
 const ENCODING utf32_encoding = {
+    enum_encoding_utf32,
     "utf32",
     4,
     utf32_characters,
