@@ -1,7 +1,7 @@
 /* op.h
  *  Copyright: (When this is determined...it will go here)
  *  CVS Info
- *     $Id: op.h,v 1.1 2001/10/14 00:43:50 gregor Exp $
+ *     $Id: op.h,v 1.9 2002/03/04 03:17:21 josh Exp $
  *  Overview:
  *     Header file for op functions.
  *  Data Structure and Algorithms:
@@ -18,29 +18,32 @@
 #define PARROT_MAX_ARGS 10
 
 typedef enum {
-  PARROT_MANUAL_OP,
-  PARROT_AUTO_OP
+    PARROT_INLINE_OP,
+    PARROT_FUNCTION_OP
 } op_type_t;
 
 typedef enum {
-  PARROT_ARG_OP,
+    PARROT_ARG_OP,
 
-  PARROT_ARG_IC,
-  PARROT_ARG_NC,
-  PARROT_ARG_PC,
-  PARROT_ARG_SC,
+    PARROT_ARG_IC,
+    PARROT_ARG_NC,
+    PARROT_ARG_PC,
+    PARROT_ARG_SC,
 
-  PARROT_ARG_I,
-  PARROT_ARG_N,
-  PARROT_ARG_P,
-  PARROT_ARG_S
+    PARROT_ARG_I,
+    PARROT_ARG_N,
+    PARROT_ARG_P,
+    PARROT_ARG_S
 } arg_type_t;
 
 #define PARROT_ARG_OP 0
 
 /* NOTE: Sure wish we could put the types here... */
 
-typedef opcode_t *(*op_func_t)();
+struct Parrot_Interp;
+
+typedef opcode_t *(*op_func_t)(opcode_t *, struct Parrot_Interp *);
+typedef void **(*op_func_prederef_t)(void **, struct Parrot_Interp *);
 
 
 /*
@@ -51,12 +54,12 @@ typedef opcode_t *(*op_func_t)();
 */
 
 typedef struct {
-    op_type_t  type;
-    char *     name;
-    char *     full_name;
-    char *     func_name;
-    char *     body;
-    INTVAL     arg_count; /* Includes opcode as one arg */
+    op_type_t type;
+    const char *name;
+    const char *full_name;
+    const char *func_name;
+    const char *body;
+    INTVAL arg_count;           /* Includes opcode as one arg */
     arg_type_t types[PARROT_MAX_ARGS];
 } op_info_t;
 
